@@ -63,8 +63,9 @@ class DropMenu;
 
 class KIO::DropMenu : public QMenu
 {
+    Q_OBJECT
 public:
-    DropMenu(QWidget *parent = nullptr);
+    explicit DropMenu(QWidget *parent = nullptr);
     ~DropMenu();
 
     void addCancelAction();
@@ -175,7 +176,7 @@ DropMenu::DropMenu(QWidget *parent)
     : QMenu(parent),
       m_extraActionsSeparator(nullptr)
 {
-    m_cancelAction = new QAction(i18n("C&ancel") + '\t' + QKeySequence(Qt::Key_Escape).toString(), this);
+    m_cancelAction = new QAction(i18n("C&ancel") + QLatin1Char('\t') + QKeySequence(Qt::Key_Escape).toString(), this);
     m_cancelAction->setIcon(QIcon::fromTheme(QStringLiteral("process-stop")));
 
     m_lastSeparator = new QAction(this);
@@ -192,10 +193,10 @@ void DropMenu::addExtraActions(const QList<QAction *> &appActions, const QList<Q
     removeAction(m_cancelAction);
 
     removeAction(m_extraActionsSeparator);
-    for (QAction *action : m_appActions) {
+    for (QAction *action : qAsConst(m_appActions)) {
         removeAction(action);
     }
-    for (QAction *action : m_pluginActions) {
+    for (QAction *action : qAsConst(m_pluginActions)) {
         removeAction(action);
     }
 
@@ -284,6 +285,10 @@ int DropJobPrivate::determineDropAction()
 
     const bool trashing = m_destUrl.scheme() == QLatin1String("trash");
     if (trashing) {
+        if (allItemsAreFromTrash) {
+            qCDebug(KIO_WIDGETS) << "Dropping items from trash to trash";
+            return KIO::ERR_DROP_ON_ITSELF;
+        }
         m_dropAction = Qt::MoveAction;
         if (!q->uiDelegateExtension()->askDeleteConfirmation(m_urls, KIO::JobUiDelegate::Trash, KIO::JobUiDelegate::DefaultConfirmation)) {
             return KIO::ERR_USER_CANCELED;
@@ -322,6 +327,7 @@ void DropJobPrivate::fillPopupMenu(KIO::DropMenu *popup)
     // TODO: Determining the mimetype of the source URLs is difficult for remote URLs,
     // we would need to KIO::stat each URL in turn, asynchronously....
     KFileItemList fileItems;
+    fileItems.reserve(m_urls.size());
     foreach (const QUrl &url, m_urls) {
         fileItems.append(KFileItem(url));
     }
@@ -334,21 +340,21 @@ void DropJobPrivate::fillPopupMenu(KIO::DropMenu *popup)
     const bool sMoving = itemProps.supportsMoving();
 
     QString seq = QKeySequence(Qt::ShiftModifier).toString();
-    Q_ASSERT(seq.endsWith('+'));
+    Q_ASSERT(seq.endsWith(QLatin1Char('+')));
     seq.chop(1); // chop superfluous '+'
-    QAction* popupMoveAction = new QAction(i18n("&Move Here") + '\t' + seq, popup);
+    QAction* popupMoveAction = new QAction(i18n("&Move Here") + QLatin1Char('\t') + seq, popup);
     popupMoveAction->setIcon(QIcon::fromTheme(QStringLiteral("go-jump")));
     popupMoveAction->setData(QVariant::fromValue(Qt::MoveAction));
     seq = QKeySequence(Qt::ControlModifier).toString();
-    Q_ASSERT(seq.endsWith('+'));
+    Q_ASSERT(seq.endsWith(QLatin1Char('+')));
     seq.chop(1);
-    QAction* popupCopyAction = new QAction(i18n("&Copy Here") + '\t' + seq, popup);
+    QAction* popupCopyAction = new QAction(i18n("&Copy Here") + QLatin1Char('\t') + seq, popup);
     popupCopyAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
     popupCopyAction->setData(QVariant::fromValue(Qt::CopyAction));
     seq = QKeySequence(Qt::ControlModifier + Qt::ShiftModifier).toString();
-    Q_ASSERT(seq.endsWith('+'));
+    Q_ASSERT(seq.endsWith(QLatin1Char('+')));
     seq.chop(1);
-    QAction* popupLinkAction = new QAction(i18n("&Link Here") + '\t' + seq, popup);
+    QAction* popupLinkAction = new QAction(i18n("&Link Here") + QLatin1Char('\t') + seq, popup);
     popupLinkAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-link")));
     popupLinkAction->setData(QVariant::fromValue(Qt::LinkAction));
 
@@ -385,8 +391,8 @@ void DropJobPrivate::addPluginActions(KIO::DropMenu *popup, const KFileItemListP
         if (factory) {
             KIO::DndPopupMenuPlugin *plugin = factory->create<KIO::DndPopupMenuPlugin>();
             if (plugin) {
-                auto actions = plugin->setup(itemProps, m_destUrl);
-                foreach (auto action, actions) {
+                const auto actions = plugin->setup(itemProps, m_destUrl);
+                for (auto action : actions) {
                     action->setParent(popup);
                 }
                 m_pluginActions += actions;
@@ -403,7 +409,7 @@ void DropJob::setApplicationActions(const QList<QAction *> &actions)
 
     d->m_appActions = actions;
 
-    for (KIO::DropMenu *menu : d->m_menus) {
+    for (KIO::DropMenu *menu : qAsConst(d->m_menus)) {
         menu->addExtraActions(d->m_appActions, d->m_pluginActions);
     }
 }
@@ -546,7 +552,8 @@ void DropJobPrivate::handleDropToExecutable()
     Q_Q(DropJob);
     // Launch executable for each of the files
     QStringList args;
-    Q_FOREACH(const QUrl &url, m_urls) {
+    args.reserve(m_urls.size());
+    for (const QUrl &url : qAsConst(m_urls)) {
         args << url.toLocalFile(); // assume local files
     }
     QProcess::startDetached(m_destUrl.toLocalFile(), args);
@@ -569,3 +576,4 @@ DropJob * KIO::drop(const QDropEvent *dropEvent, const QUrl &destUrl, JobFlags f
 }
 
 #include "moc_dropjob.cpp"
+#include "dropjob.moc"
